@@ -1,11 +1,9 @@
 
 from __future__ import print_function
 
+import os
 import subprocess
 import sys
-import os
-import fileinput
-import fnmatch
 import warnings
 
 BASE_DIR = os.path.dirname(os.path.abspath(__file__))
@@ -19,10 +17,18 @@ os.environ['DJANGO_SETTINGS_MODULE'] = 'openstack_dashboard.settings'
 
 # -- General configuration ----------------------------------------------------
 
-# Add any Sphinx extension module names here, as strings. They can be extensions
-# coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = ['sphinx.ext.autodoc', 'sphinx.ext.doctest', 'sphinx.ext.todo',
-              'sphinx.ext.viewcode']
+# Add any Sphinx extension module names here, as strings. They can be
+# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
+extensions = ['sphinx.ext.autodoc',
+              'sphinx.ext.doctest',
+              'sphinx.ext.todo',
+              'sphinx.ext.viewcode',
+              'openstackdocstheme']
+
+# openstackdocstheme options
+repository_name = 'openstack/ec2-api'
+bug_project = 'ec2-api'
+bug_tag = ''
 
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
 # text edit cycles.
@@ -38,7 +44,7 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-project = 'ec2-api'
+project = 'EC2API Service'
 copyright = '2015, OpenStack Foundation'
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
@@ -55,13 +61,21 @@ pygments_style = 'sphinx'
 
 # The theme to use for HTML and HTML Help pages.  Major themes that come with
 # Sphinx are currently 'default' and 'sphinxdoc'.
-#html_theme_path = ["."]
-#html_theme = '_theme'
-#html_static_path = ['static']
+# html_theme_path = ["."]
+# html_theme = '_theme'
+# html_static_path = ['static']
+html_theme = 'openstackdocs'
+
+html_last_updated_fmt = '%Y-%m-%d %H:%M'
+# Theme options are theme-specific and customize the look and feel of a theme
+# further.  For a list of options available for each theme, see the
+# documentation.
+html_theme_options = {"sidebar_mode": "toc"}
 
 # Output file base name for HTML help builder.
 htmlhelp_basename = '%sdoc' % project
 
+
 git_cmd = ["git", "log", "--pretty=format:'%ad, commit %h'", "--date=local",
     "-n1"]
 try:
