@@ -26,13 +26,13 @@ from ec2api.api import ec2utils
 from ec2api.api import validator
 from ec2api.db import api as db_api
 from ec2api import exception
-from ec2api.i18n import _, _LW
+from ec2api.i18n import _
 
 
 ec2_opts = [
-    cfg.BoolOpt('full_vpc_support',
-                default=True,
-                help='True if server supports Neutron for full VPC access'),
+    cfg.BoolOpt('disable_ec2_classic',
+                help='True if server does not support EC2 Classic mode '
+                     'in favor of default VPC'),
 ]
 
 CONF = cfg.CONF
@@ -92,7 +92,7 @@ class OnCrashCleaner(object):
                         formatted_args += ', '
                     formatted_args += kwargs_string
                 LOG.warning(
-                    _LW('Error cleaning up %(name)s(%(args)s)') %
+                    'Error cleaning up %(name)s(%(args)s)' %
                     {'name': name, 'args': formatted_args},
                     exc_info=True)
                 pass
@@ -307,6 +307,9 @@ class UniversalDescriber(object):
         if item is None and self.KIND not in VPC_KINDS:
             item = ec2utils.auto_create_db_item(self.context, self.KIND,
                                                 self.get_id(os_item))
+            LOG.info(
+                'Item %(item)s was updated to %(os_item)s.',
+                {'item': str(item), 'os_item': str(os_item)})
         return item
 
     def get_id(self, os_item):
@@ -316,6 +319,7 @@ class UniversalDescriber(object):
         return os_item['name']
 
     def delete_obsolete_item(self, item):
+        LOG.info('Deleting obsolete item %(item)s', {'item': str(item)})
         db_api.delete_item(self.context, item['id'])
 
     def is_filtering_value_found(self, filter_value, value):
@@ -371,16 +375,21 @@ class UniversalDescriber(object):
 
         next_item = 0
         if next_token:
-            next_item = int(base64.b64decode(next_token))
+            next_item = int(base64.b64decode(next_token).decode())
         if next_item:
             formatted_items = formatted_items[next_item:]
         if max_results and max_results < len(formatted_items):
-            self.next_token = base64.b64encode(str(next_item + max_results))
+            self.next_token = base64.b64encode(
+                str(next_item + max_results).encode())
             formatted_items = formatted_items[:max_results]
 
         return formatted_items
 
-    def handle_unpaired_item(self, item, formatted_items):
+    def is_selected_item(self, context, os_item_name, item):
+        return (os_item_name in self.names or
+                (item and item['id'] in self.ids))
+
+    def handle_unpaired_item(self, item):
         self.delete_obsolete_item(item)
 
     def describe(self, context, ids=None, names=None, filter=None,
@@ -404,13 +413,16 @@ class UniversalDescriber(object):
             os_item_name = self.get_name(os_item)
             os_item_id = self.get_id(os_item)
             item = self.items_dict.get(os_item_id, None)
+            if item:
+                paired_items_ids.add(item['id'])
             # NOTE(Alex): Filter out items not requested in names or ids
             if (self.selective_describe and
-                    not (os_item_name in self.names or
-                         (item and item['id'] in self.ids))):
+                    not self.is_selected_item(context, os_item_name, item)):
                 continue
             # NOTE(Alex): Autoupdate DB for autoupdatable items
             item = self.auto_update_db(item, os_item)
+            # NOTE(andrey-mp): save item id again
+            # (if item has created by auto update)
             if item:
                 paired_items_ids.add(item['id'])
             formatted_item = self.format(item, os_item)
@@ -424,8 +436,14 @@ class UniversalDescriber(object):
                 formatted_items.append(formatted_item)
         # NOTE(Alex): delete obsolete items
         for item in self.items:
-            if item['id'] not in paired_items_ids:
-                self.handle_unpaired_item(item, formatted_items)
+            if item['id'] in paired_items_ids:
+                continue
+            formatted_item = self.handle_unpaired_item(item)
+            if formatted_item:
+                if not self.filtered_out(formatted_item, filter):
+                    formatted_items.append(formatted_item)
+                if item['id'] in self.ids:
+                    self.ids.remove(item['id'])
         # NOTE(Alex): some requested items are not found
         if self.ids or self.names:
             params = {'id': next(iter(self.ids or self.names))}
