@@ -26,7 +26,7 @@ import six
 from ec2api import clients
 from ec2api.db import api as db_api
 from ec2api import exception
-from ec2api.i18n import _, _LE
+from ec2api.i18n import _
 
 LOG = logging.getLogger(__name__)
 
@@ -125,7 +125,7 @@ def dict_from_dotted_str(items):
 
 def _render_dict(el, data):
     try:
-        for key, val in six.iteritems(data):
+        for key, val in data.items():
             sub_el = etree.SubElement(el, key)
             _render_data(sub_el, val)
     except Exception:
@@ -203,7 +203,7 @@ def is_ec2_timestamp_expired(request, expires=None):
                         timeutils.is_newer_than(query_time, expires))
         return False
     except ValueError:
-        LOG.exception(_("Timestamp is invalid: "))
+        LOG.exception("Timestamp is invalid: ")
         return True
 
 
@@ -438,7 +438,7 @@ def get_os_image_mappings(os_image_properties):
                 new_bdm = create_virtual_bdm(bdm.get('device_name'),
                                              virtual_name)
             else:
-                new_bdm = {key: val for key, val in six.iteritems(bdm)
+                new_bdm = {key: val for key, val in bdm.items()
                            if key in LEGACY_BDM_FIELDS}
                 if bdm.get('snapshot_id'):
                     new_bdm.update({'source_type': 'snapshot',
@@ -461,16 +461,15 @@ def get_os_public_network(context):
     if len(os_networks) != 1:
         if CONF.external_network:
             if len(os_networks) == 0:
-                msg = _LE("No external network with name '%s' is found")
+                msg = "No external network with name '%s' is found"
             else:
-                msg = _LE("More than one external network with name '%s' "
-                          "is found")
+                msg = "More than one external network with name '%s' is found"
             LOG.error(msg, CONF.external_network)
         else:
             if len(os_networks) == 0:
-                msg = _LE('No external network is found')
+                msg = 'No external network is found'
             else:
-                msg = _LE('More than one external network is found')
+                msg = 'More than one external network is found'
             LOG.error(msg)
         raise exception.Unsupported(_('Feature is restricted by OS admin'))
     return os_networks[0]
@@ -482,6 +481,25 @@ def get_attached_gateway(context, vpc_id, gateway_kind):
                  if gw['vpc_id'] == vpc_id), None)
 
 
+_check_and_create_default_vpc = None
+
+
+def check_and_create_default_vpc(context):
+    return _check_and_create_default_vpc(context)
+
+
+def set_check_and_create_default_vpc(check_and_create_default_vpc):
+    global _check_and_create_default_vpc
+    _check_and_create_default_vpc = check_and_create_default_vpc
+
+
+def get_default_vpc(context):
+    default_vpc = check_and_create_default_vpc(context)
+    if not default_vpc:
+        raise exception.VPCIdNotSpecified()
+    return default_vpc
+
+
 # NOTE(ft): following functions are copied from various parts of Nova
 
 _ephemeral = re.compile('^ephemeral(\d|[1-9]\d+)$')
@@ -511,3 +529,32 @@ def block_device_properties_root_device_name(properties):
                      if bdm['virtual'] == 'root'), None)
     else:
         return None
+
+
+_ISO8601_TIME_FORMAT_SUBSECOND = '%Y-%m-%dT%H:%M:%S.%f'
+_ISO8601_TIME_FORMAT = '%Y-%m-%dT%H:%M:%S'
+
+
+def isotime(at=None, subsecond=False):
+    """Stringify time in ISO 8601 format."""
+
+    # Python provides a similar instance method for datetime.datetime objects
+    # called isoformat(). The format of the strings generated by isoformat()
+    # have a couple of problems:
+    # 1) The strings generated by isotime are used in tokens and other public
+    #    APIs that we can't change without a deprecation period. The strings
+    #    generated by isoformat are not the same format, so we can't just
+    #    change to it.
+    # 2) The strings generated by isoformat do not include the microseconds if
+    #    the value happens to be 0. This will likely show up as random failures
+    #    as parsers may be written to always expect microseconds, and it will
+    #    parse correctly most of the time.
+
+    if not at:
+        at = timeutils.utcnow()
+    st = at.strftime(_ISO8601_TIME_FORMAT
+                     if not subsecond
+                     else _ISO8601_TIME_FORMAT_SUBSECOND)
+    tz = at.tzinfo.tzname(None) if at.tzinfo else 'UTC'
+    st += ('Z' if tz == 'UTC' else tz)
+    return st
